@@ -114,7 +114,11 @@ pluma_file_browser_view_finalize (GObject * object)
 	PlumaFileBrowserView *obj = PLUMA_FILE_BROWSER_VIEW(object);
 	
 	if (obj->priv->hand_cursor)
-		gdk_cursor_unref(obj->priv->hand_cursor);
+#if GTK_CHECK_VERSION (3, 0, 0)
+		g_object_unref (obj->priv->hand_cursor);
+#else
+		gdk_cursor_unref (obj->priv->hand_cursor);
+#endif
 
 	if (obj->priv->hover_path)
 		gtk_tree_path_free (obj->priv->hover_path);
@@ -125,7 +129,11 @@ pluma_file_browser_view_finalize (GObject * object)
 		obj->priv->expand_state = NULL;
 	}
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	g_object_unref (obj->priv->busy_cursor);
+#else
 	gdk_cursor_unref (obj->priv->busy_cursor);
+#endif
 
 	G_OBJECT_CLASS (pluma_file_browser_view_parent_class)->
 	    finalize (object);
@@ -308,7 +316,12 @@ set_click_policy_property (PlumaFileBrowserView            *obj,
 
 	if (click_policy == PLUMA_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
 		if (obj->priv->hand_cursor == NULL)
+#if GTK_CHECK_VERSION (3, 16, 0)
+			display = gtk_widget_get_display (GTK_WIDGET (obj));
+			obj->priv->hand_cursor = gdk_cursor_new_for_display (display, GDK_HAND2);
+#else
 			obj->priv->hand_cursor = gdk_cursor_new(GDK_HAND2);
+#endif
 	} else if (click_policy == PLUMA_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE) {
 		if (obj->priv->hover_path != NULL) {
 			if (gtk_tree_model_get_iter (GTK_TREE_MODEL (obj->priv->model),
@@ -331,7 +344,11 @@ set_click_policy_property (PlumaFileBrowserView            *obj,
 		}
 
 		if (obj->priv->hand_cursor) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+			g_object_unref (obj->priv->hand_cursor);
+#else
 			gdk_cursor_unref (obj->priv->hand_cursor);
+#endif
 			obj->priv->hand_cursor = NULL;
 		}
 	}
@@ -945,6 +962,9 @@ cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
 static void
 pluma_file_browser_view_init (PlumaFileBrowserView * obj)
 {
+#if GTK_CHECK_VERSION (3, 16, 0)
+	GdkDisplay *display;
+#endif
 	obj->priv = PLUMA_FILE_BROWSER_VIEW_GET_PRIVATE (obj);
 
 	obj->priv->column = gtk_tree_view_column_new ();
@@ -979,7 +999,12 @@ pluma_file_browser_view_init (PlumaFileBrowserView * obj)
 						G_N_ELEMENTS (drag_source_targets),
 						GDK_ACTION_COPY);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+	display = gtk_widget_get_display (GTK_WIDGET (obj));
+	obj->priv->busy_cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
+#else
 	obj->priv->busy_cursor = gdk_cursor_new (GDK_WATCH);
+#endif
 }
 
 static gboolean
