@@ -42,6 +42,10 @@
 
 #define PRINTER_DPI (72.)
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 struct _PlumaPrintPreviewPrivate
 {
 	GtkPrintOperation *operation;
@@ -83,7 +87,11 @@ struct _PlumaPrintPreviewPrivate
 	guint cur_page;
 };
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+G_DEFINE_TYPE (PlumaPrintPreview, pluma_print_preview, GTK_TYPE_BOX)
+#else
 G_DEFINE_TYPE (PlumaPrintPreview, pluma_print_preview, GTK_TYPE_VBOX)
+#endif
 
 static void 
 pluma_print_preview_get_property (GObject    *object,
@@ -997,6 +1005,15 @@ pluma_print_preview_init (PlumaPrintPreview *preview)
 	priv->context = NULL;
 	priv->gtk_preview = NULL;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    GtkStyleContext *context;
+
+    context = gtk_widget_get_style_context (GTK_WIDGET (preview));
+    gtk_style_context_add_class (context, "pluma-print-preview");
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (preview),
+	                                GTK_ORIENTATION_VERTICAL);
+#endif
+
 	create_bar (preview);
 	create_preview_layout (preview);
 
